/***************************************************************************
                          kledtoggle.h  -  description
                             -------------------
    begin                : Sat Jan 26 2002
    copyright            : (C) 2002-2003 by Aurelien Jarno
    email                : aurelien@aurel32.net
 ***************************************************************************/

/***************************************************************************
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 ***************************************************************************/

#ifndef KLedTOGGLE_H
#define KLedTOGGLE_H

#ifdef HAVE_CONFIG_H
  #include <config.h>
#endif

// include files for Qt
#include <qwidget.h>

// include files for KDE
#include <kled.h>

class KLedToggle : public KLed
{
   Q_OBJECT
public: 
	KLedToggle(QWidget *parent=0, const char *name=0);
	~KLedToggle();
	
protected:
  void mousePressEvent(QMouseEvent *event);

signals:
  void toggled();	
};

#endif
